@@ -1,6 +1,7 @@
 from . import TestCase
 from .helpers import MockUser, MockConsumer
 from nose.tools import *
+from mock import patch
 
 from flask import json, url_for
 
@@ -24,14 +25,14 @@ class TestStore(TestCase):
         self.ctx.pop()
         super(TestStore, self).teardown()
 
-    def _create_annotation(self, **kwargs):
+    def _create_annotation(self, refresh=True, **kwargs):
         opts = {
             'user': self.user.id,
             'consumer': self.user.consumer.key
         }
         opts.update(kwargs)
         ann = Annotation(**opts)
-        ann.save()
+        ann.save(refresh=refresh)
         return ann
 
     def _get_annotation(self, id_):
@@ -113,6 +114,26 @@ class TestStore(TestCase):
         assert ann['user'] == self.user.id, "annotation 'user' field should not be futzable by API"
         assert ann['consumer'] == self.user.consumer.key, "annotation 'consumer' field should not be used by API"
 
+    @patch('annotator.store.json')
+    @patch('annotator.store.Annotation')
+    def test_create_refresh(self, ann_mock, json_mock):
+        json_mock.dumps.return_value = "{}"
+        response = self.cli.post('/api/annotations?refresh=true',
+                                 data="{}",
+                                 content_type='application/json',
+                                 headers=self.headers)
+        ann_mock.return_value.save.assert_called_once_with(refresh=True)
+
+    @patch('annotator.store.json')
+    @patch('annotator.store.Annotation')
+    def test_create_disable_refresh(self, ann_mock, json_mock):
+        json_mock.dumps.return_value = "{}"
+        response = self.cli.post('/api/annotations?refresh=false',
+                                 data="{}",
+                                 content_type='application/json',
+                                 headers=self.headers)
+        ann_mock.return_value.save.assert_called_once_with(refresh=False)
+
     def test_read(self):
         kwargs = dict(text=u"Foo", id='123')
         self._create_annotation(**kwargs)
@@ -234,8 +255,6 @@ class TestStore(TestCase):
         anno2 = self._create_annotation(uri=uri1, text=uri1 + uri1, user=user2)
         anno3 = self._create_annotation(uri=uri2, text=uri2, user=user)
 
-        es.conn.refresh(timesleep=0.01)
-
         res = self._get_search_results()
         assert_equal(res['total'], 3)
 
@@ -251,7 +270,7 @@ class TestStore(TestCase):
 
     def test_search_limit(self):
         for i in xrange(250):
-            self._create_annotation()
+            self._create_annotation(refresh=False)
 
         es.conn.refresh(timesleep=0.01)
 
@@ -273,7 +292,7 @@ class TestStore(TestCase):
 
     def test_search_offset(self):
         for i in xrange(250):
-            self._create_annotation()
+            self._create_annotation(refresh=False)
 
         es.conn.refresh(timesleep=0.01)
 
